@@ -594,7 +594,8 @@ def mount_image(ctx,imagepath,mountpath,firmware_path,not_interactive):
 @cli.command()
 @click.argument('imagepath')
 @click.option('-n','--image-name')
-def iso_to_docker(imagepath,image_name:str=None):
+@click.option('-p','--platform')
+def iso_to_docker(imagepath,image_name:str=None,platform:str=None):
     if not image_name:
         image_name = os.path.basename(imagepath).split('.',1)[0]
     with tempfile.TemporaryDirectory() as outdir:
@@ -605,7 +606,11 @@ def iso_to_docker(imagepath,image_name:str=None):
                 print(f'tar the tempdir: {tempdir}')
                 tar_directory.callback(tempdir,tar_path,sudo=True)
         print(f'import the {tar_path} to docker')
-        subprocess.run(['docker','import',tar_path,image_name])
+        cmd = ['docker','import',tar_path,image_name]
+        if platform is not None:
+            cmd.append('--platform')
+            cmd.append(platform)
+        subprocess.run(cmd)
     click.echo(f'Docker image {image_name} sucessfully created')
 
 
